@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::RoutesAuthDBI;
 use Mojo::Base 'Mojolicious::Plugin::Authentication';
 
-our $VERSION = '0.301';
+our $VERSION = '0.302';
 
 my $access;# 
 my $pkg = __PACKAGE__;
@@ -61,7 +61,7 @@ sub access_instance {# auth, routes and access methods
   return (bless $conf, $class)->init_class;
 }
 
-sub admin_controller {# web interface
+sub admin_controller {# web interface :)
   my ($self, $app, $conf) = @_;
   my $class  = _load_mod( $conf->{namespace}, $conf->{controller});
   return (bless $conf, $class)->init_class;
@@ -133,6 +133,10 @@ sub access {# add_condition
 
 Mojolicious::Plugin::RoutesAuthDBI - Generate routes from sql-table, make authentication and make restrict access (authorization) to route with users/roles tables. Plugin makes an auth operations throught the plugin L<Mojolicious::Plugin::Authentication> on which is based.
 
+=head1 DIAGRAM DB DESIGN
+
+See L<https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>
+
 =head1 SYNOPSIS
 
     $app->plugin('RoutesAuthDBI',
@@ -260,6 +264,7 @@ If you changed the routes table then kill -HUP or reload app to regenerate route
 =head1 SEE ALSO
 
 L<Mojolicious::Plugin::Authentication>
+
 L<Mojolicious::Plugin::Authorization>
 
 =head1 AUTHOR
