@@ -17,6 +17,10 @@ my $sth;#sth hub
 
 Mojolicious::Plugin::RoutesAuthDBI::Access - Generation routes, authentication and controll access to routes trought sintax of ->over(...), see L<Mojolicious::Routes::Route#over>
 
+=head1 DIAGRAM DB DESIGN
+
+See L<https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>
+
 =head2 Access controll flow
 
 =over 4
@@ -51,6 +55,7 @@ Route to callback (no ref to controller, defined I<callback> column (as text "su
 
 =back
 
+
 =head1 SYNOPSIS
 
     $app->plugin('RoutesAuthDBI', 
