@@ -15,6 +15,10 @@ my $sth;#sth hub
 
 Mojolicious::Plugin::RoutesAuthDBI::Admin - is a Mojolicious::Controller for manage admin operations on DBI tables: controllers, actions, routes, roles, users.
 
+=head1 DIAGRAM DB DESIGN
+
+See L<https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>
+
 =head1 SYNOPSIS
 
     $app->plugin('RoutesAuthDBI', 
@@ -106,7 +110,6 @@ $pkg
 You are signed as:
 @{[$c->dumper( $c->auth_user)]}
 
-@{[$c->access_instance]}
 
 ADMIN ROUTES
 ===
@@ -124,7 +127,8 @@ sub sign {
   my $c = shift;
   
   $c->authenticate($c->stash('login') || $c->param('login'), $c->stash('pass') || $c->param('pass'))
-    and $c->render(format=>'txt', text=>__PACKAGE__ . "\n\nSuccessfull signed! ".$c->dumper( $c->auth_user))
+    and $c->redirect_to("admin home")
+    #~ and $c->render(format=>'txt', text=>__PACKAGE__ . "\n\nSuccessfull signed! ".$c->dumper( $c->auth_user))
     and return;
     
   
@@ -150,7 +154,8 @@ sub new_user {
     and $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-User already exists!
+User already exists
+===
 
 @{[$c->dumper( $r)]}
 TXT
@@ -162,7 +167,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
-Success sign up new user!
+Success sign up new user
+===
 
 @{[$c->dumper( $r)]}
 TXT
@@ -194,7 +200,8 @@ sub trust_new_user {
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
-Success sign up new trust-user!
+Success sign up new trust-admin-user
+===
 
 USER:
 @{[$c->dumper( $u)]}
@@ -215,7 +222,8 @@ sub new_role {
 	$c->render(format=>'txt', text=><<TXT)
 $pkg
 
-Exists role!
+Role exists
+===
 
 @{[$c->dumper( $r)]}
 
@@ -227,7 +235,8 @@ TXT
 	$c->render(format=>'txt', text=><<TXT);
 $pkg
 
-Success created role!
+Success created role
+===
 
 @{[$c->dumper( $r)]}
 
@@ -243,7 +252,8 @@ sub user_roles {
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-No such user [$user]!
+No such user [$user]
+===
 
 TXT
     and return
@@ -254,6 +264,9 @@ TXT
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
+List of user roles (@{[scalar @$r]})
+===
+
 USER
 @{[$c->dumper( $u)]}
 
@@ -273,7 +286,8 @@ sub new_role_user {
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-Can't create new role by only digits[$role] in name!
+Can't create new role by only digits[$role] in name
+===
 
 TXT
     and return
@@ -286,7 +300,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-No such user [$user]!
+No such user [$user]
+===
 
 TXT
     and return
@@ -296,7 +311,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-Allready ref ROLE->USER!
+Allready ref ROLE -> USER
+===
 
 @{[$c->dumper( $ref)]}
 TXT
@@ -308,7 +324,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
-Success create ref ROLE->USER!
+Success create ref ROLE -> USER
+===
 
 @{[$c->dumper( $ref)]}
 TXT
@@ -325,7 +342,8 @@ sub del_role_user {# удалить связь пользователя с ро
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-No such role [$role]!
+No such role [$role]
+===
 
 TXT
     and return
@@ -337,7 +355,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-No such user [$user]!
+No such user [$user]
+===
 
 TXT
     and return
@@ -347,7 +366,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-Success delete ref ROLE[$role]->USER[$user]!
+Success delete ref ROLE[$role] -> USER[$user]
+===
 
 @{[$c->dumper( $ref)]}
 TXT
@@ -357,7 +377,7 @@ TXT
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-There is no ref ROLE[$role]->USER[$user]!
+There is no ref ROLE[$role] -> USER[$user]
 
 TXT
   
@@ -374,7 +394,8 @@ sub disable_role {
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-No such role [$role]!
+No such role [$role]
+===
 
 TXT
     and return
@@ -383,7 +404,8 @@ TXT
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-Success @{[$k->{$a}]} role!
+Success @{[$k->{$a}]} role
+===
 
 @{[$c->dumper( $r)]}
 
@@ -402,7 +424,8 @@ sub role_users {# все пользователи роли по запросу /
   $c->render(format=>'txt', text=><<TXT)
 $pkg
 
-No such role [$role]!
+No such role [$role]
+===
 
 TXT
     and return
@@ -413,6 +436,7 @@ TXT
 $pkg
 
 All @{[scalar @$u]} users by role [$r->{name}]
+===
 
 @{[$c->dumper( $u)]}
 TXT
@@ -449,7 +473,7 @@ sub controllers {
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
-CONTROLLERS TABLE
+CONTROLLERS TABLE (@{[scalar @$list]})
 ===
 
 @{[$c->dumper( $list)]}
@@ -488,7 +512,7 @@ sub actions {
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
-Actions list
+ACTIONS list (@{[scalar @$list]})
 ===
 
 @{[$c->dumper( $list )]}
@@ -501,7 +525,7 @@ sub routes {
   $c->render(format=>'txt', text=><<TXT);
 $pkg
 
-Routes list
+ROUTES list (@{[scalar @$list]})
 ===
 
 @{[$c->dumper( $list )]}
